colour.difference — Colour 0.3.0 documentation

# Source code for colour.difference

    #!/usr/bin/env python
    # -*- coding: utf-8 -*-

    from __future__ import absolute_import

    from .delta_e import (
        DELTA_E_METHODS,
        delta_E,
        delta_E_CIE_1976,
        delta_E_CIE_1994,
        delta_E_CIE_2000,
        delta_E_CMC)

    __all__ = ['DELTA_E_METHODS',
               'delta_E',
               'delta_E_CIE_1976',
               'delta_E_CIE_1994',
               'delta_E_CIE_2000',
               'delta_E_CMC']